# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import sys
from .vars import _ExportableConfig

sys.modules[__name__].__class__ = _ExportableConfig
