# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .deployment import *
from .gateway_fqdn import *
from .gateway_name import *
from .kubernetes import *
from .network import *
from .provider import *
from .scheduler import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_threefold.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_threefold.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "threefold",
  "mod": "index",
  "fqn": "pulumi_threefold",
  "classes": {
   "threefold:index:Deployment": "Deployment",
   "threefold:index:GatewayFQDN": "GatewayFQDN",
   "threefold:index:GatewayName": "GatewayName",
   "threefold:index:Kubernetes": "Kubernetes",
   "threefold:index:Network": "Network",
   "threefold:index:Scheduler": "Scheduler"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "threefold",
  "token": "pulumi:providers:threefold",
  "fqn": "pulumi_threefold",
  "class": "Provider"
 }
]
"""
)
